# Select Item to change

- Recover deleted Items
- Add Item

MockedCsrfTokenNode
Action:
0 of 6 selected

| Producer | Item | Kind | Location | Received date | Last update
--- | --- | --- | --- | --- | --- | ---
| - | main item 1 | - | - | - | Jan. 1, 2000, 1:01 a.m.
| - | main item 1 › sub item 1.1 | - | - | - | Jan. 1, 2000, 1:02 a.m.
| - | main item 1 › sub item 1.2 | - | - | - | Jan. 1, 2000, 1:03 a.m.
| - | main item 2 | - | - | - | Jan. 1, 2000, 1:04 a.m.
| - | main item 2 › sub item 2.1 | - | - | - | Jan. 1, 2000, 1:05 a.m.
| - | main item 2 › sub item 2.2 | - | - | - | Jan. 1, 2000, 1:06 a.m.

6 Items